//-----------------
// un-tweaks
//-----------------
 matrix WorldVP:WorldViewProjection; 

//-----------------
// tweaks
//-----------------
 float blurWidth <> = 0.015f;
 float Brightness <> = 0.15f;

//-----------------
// Texture
//-----------------
 texture screen 
    <
    	string Name = " ";
    >;
 sampler2D screen_sample=sampler_state 
    {
	Texture=<screen>;
   	ADDRESSU=CLAMP;
        ADDRESSV=CLAMP;
        ADDRESSW=CLAMP;
    };

//-----------------
// structs 
//-----------------
 struct input
     {
 	float4 pos : POSITION; 
 	float2 UV  : TEXCOORD; 
     };
 struct output
     {
	float4 out_pos  : POSITION;
  	float2 uva 	: TEXCOORD0;
  	float2 uvb 	: TEXCOORD1;
  	float2 uvc 	: TEXCOORD2;
  	float2 uvd 	: TEXCOORD3;
      };
 struct outputT
     {
 	float4 opos    : POSITION;  
 	float2 uv      : TEXCOORD0;  
     };

//-----------------
// vertex shader
//-----------------
 outputT VSTone(input IN) 
     {
 	outputT OUT;
 	OUT.opos=mul(IN.pos,WorldVP);
 	OUT.uv=IN.UV; 
 	return OUT;
    }
 output VS_blurXA(input IN)
      {
   	output OUT;
    	OUT.uva = IN.UV+blurWidth*(1*float2(0.5,0));
    	OUT.uvb = IN.UV+blurWidth*(1*float2(1.0,0)); 
    	OUT.uvc = IN.UV+blurWidth*(1*float2(1.5,0));
    	OUT.uvd = IN.UV+blurWidth*(1*float2(2.0,0));
    	OUT.out_pos  = mul(IN.pos,WorldVP);
   	return OUT;
      }
 output VS_blurXB(input IN)
      {
   	output OUT;
    	OUT.uva = IN.UV+blurWidth*(1*float2(-0.5,0));
    	OUT.uvb = IN.UV+blurWidth*(1*float2(-1.0,0)); 
    	OUT.uvc = IN.UV+blurWidth*(1*float2(-1.5,0));
    	OUT.uvd = IN.UV+blurWidth*(1*float2(-2.0,0));
    	OUT.out_pos  = mul(IN.pos,WorldVP);
   	return OUT;
      }
 output VS_blurYA(input IN)
      {
   	output OUT;
    	OUT.uva = IN.UV+blurWidth*(1*float2(0,0.5));
    	OUT.uvb = IN.UV+blurWidth*(1*float2(0,1.0)); 
    	OUT.uvc = IN.UV+blurWidth*(1*float2(0,1.5));
    	OUT.uvd = IN.UV+blurWidth*(1*float2(0,2.0));
    	OUT.out_pos  = mul(IN.pos,WorldVP);
   	return OUT;
      }
 output VS_blurYB(input IN)
      {
   	output OUT;
    	OUT.uva = IN.UV+blurWidth*(1*float2(0,-0.5));
    	OUT.uvb = IN.UV+blurWidth*(1*float2(0,-1.0)); 
    	OUT.uvc = IN.UV+blurWidth*(1*float2(0,-1.5));
    	OUT.uvd = IN.UV+blurWidth*(1*float2(0,-2.0));
    	OUT.out_pos  = mul(IN.pos,WorldVP);
   	return OUT;
      }

//-----------------
// pixel shader
//-----------------
 float4 PSTone(outputT IN)  : COLOR
     {
 	float4 color=tex2D(screen_sample,IN.uv);
	color=pow(color,2);
	return color;	
     }
 float4 PS_blurXA(output IN) : COLOR
      {
   	float4 tex=tex2D(screen_sample, IN.uva);
   	tex=tex+tex2D(screen_sample,IN.uvb);
   	tex=tex+tex2D(screen_sample,IN.uvc)/2;
   	tex=tex+tex2D(screen_sample,IN.uvd)/2;	
  	return (tex*Brightness);
      } 
 float4 PS_blurXB(output IN) : COLOR
      {
   	float4 tex=tex2D(screen_sample, IN.uva);
   	tex=tex+tex2D(screen_sample,IN.uvb);
   	tex=tex+tex2D(screen_sample,IN.uvc)/2;
   	tex=tex+tex2D(screen_sample,IN.uvd)/2;	
  	return (tex*Brightness);
      } 
 float4 PS_blurYA(output IN) : COLOR
      {
   	float4 tex=tex2D(screen_sample, IN.uva);
   	tex=tex+tex2D(screen_sample,IN.uvb);
   	tex=tex+tex2D(screen_sample,IN.uvc)/2;
   	tex=tex+tex2D(screen_sample,IN.uvd)/2;	
  	return (tex*Brightness);
      } 
 float4 PS_blurYB(output IN) : COLOR
      {
   	float4 tex=tex2D(screen_sample, IN.uva);
   	tex=tex+tex2D(screen_sample,IN.uvb);
   	tex=tex+tex2D(screen_sample,IN.uvc)/2;
   	tex=tex+tex2D(screen_sample,IN.uvd)/2;
  	return (tex*Brightness);
      } 

//-----------------
// techniques   
//-----------------
  technique Tone
      {
  	pass p1
      {		
  	vertexShader = compile vs_1_1 VSTone(); 
  	pixelShader  = compile ps_1_1 PSTone(); 	
      }
      }
 technique blurpassX
      {
	pass p1
      {
   	VertexShader = compile vs_1_1 VS_blurXA();
   	PixelShader  = compile ps_1_1 PS_blurXA();
    	SrcBlend = One;
    	DestBlend = One;
      }
  	pass p2
      {
   	VertexShader = compile vs_1_1 VS_blurXB();
   	PixelShader  = compile ps_1_1 PS_blurXB();
    	SrcBlend = One;
    	DestBlend = One;
 	AlphaBlendEnable = True;
      }
      }
 technique blurpassY
      {
	pass p1
      {
   	VertexShader = compile vs_1_1 VS_blurYA();
   	PixelShader  = compile ps_1_1 PS_blurYA();
    	SrcBlend = One;
    	DestBlend = One;
      }
  	pass p2
      {
   	VertexShader = compile vs_1_1 VS_blurYB();
   	PixelShader  = compile ps_1_1 PS_blurYB();
    	SrcBlend = One;
    	DestBlend = One;
 	AlphaBlendEnable = True;
      }
      }